@@ -1,5 +1,6 @@
-import asyncio
+import dataclasses
 import json
+import logging
 import threading
 from statsig.layer import Layer
 
@@ -183,9 +184,10 @@ class StatsigServer:
         return result
 
     def __normalize_user(self, user):
+        userCopy = dataclasses.replace(user)
         if self._options is not None and self._options._environment is not None:
-            user._statsig_environment = self._options._environment
-        return user
+            userCopy._statsig_environment = self._options._environment
+        return userCopy
 
     def _sync(self, sync_func, interval):
         while True:
@@ -201,6 +203,7 @@ class StatsigServer:
             self.__save_json_config_specs(specs)
         except ValueError:
             # JSON deconding failed, just let background thread update rulesets
+            logging.getLogger('statsig.sdk').exception('Failed to parse bootstrap_values')
             return
 
     def __save_json_config_specs(self, specs, notify=False):
